#ifndef WEBPAGE_H
#define WEBPAGE_H

#include <QWebPage>


class WebPage : public QWebPage {

    Q_OBJECT

    public:
        explicit WebPage(QObject *parent = 0);

    protected:
#ifdef Q_WS_MAEMO_5
        QString userAgentForUrl(const QUrl &url) const;
#endif
        void javaScriptConsoleMessage(const QString &message, int lineNumber, const QString &sourceId);

        bool acceptNavigationRequest(QWebFrame *frame, const QNetworkRequest &request, NavigationType type);
};

#endif // WEBPAGE_H
